{% extends "projects/projects.html" %}

{% block head %}
    {{ super() }}
    <link rel="stylesheet" type="text/css"
          href="{{ url_for('nbi.static', filename='nbi.css') }}">
    <script rel="script" type="text/javascript"
            src="{{ url_for('nbi.static', filename='nbi.js') }}">
    </script>
{% endblock %}

{% block mid_grid_section %}
    {% set search_description = 'This field can be used to search for projects
 by using their associated tags' %}
    {% include 'nbi/area_section.html' %}
    {% include 'base/search_section.html' %}
    {% include 'base/highlight_tags_section.html' %}
{% endblock %}
