{% if areas %}
    <div class="area-section">
        <div class="btn-group btn-group-justified" data-toggle="buttons">
            {% for area in areas %}
                <label class="btn btn-projects" id="{{ area[0] }}">
                    <input type="radio" name="options"> {{ area[1] }}
                </label>
            {% endfor %}
        </div>
    </div>
{% endif %}
